#!/bin/bash
#
#  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.
#
#  This file is part of the TerraLib - a Framework for building GIS enabled applications.
#
#  TerraLib is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published by
#  the Free Software Foundation, either version 3 of the License,
#  or (at your option) any later version.
#
#  TerraLib is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with TerraLib. See COPYING. If not, write to
#  TerraLib Team at <terralib-team@terralib.org>.
#
#
#  Description: Performs TerraLib installation on Linux Ubuntu.
#  Author: TerraLib Team <terralib-team@terralib.org>
#
#  Example:
#  $ ./install.sh
#

echo "*********************************************"
echo "* TerraLib Installer for Linux Ubuntu 16.04 *"
echo "*********************************************"
echo ""
sleep 1s

#
# Valid parameter val or abort script
#
function valid_operation()
{
  if [ $1 -ne 0 ]; then
    echo ""
    echo $2
    echo ""
    exit $1
  fi
}

#
# Update Ubuntu install list
#
sudo apt-get update
valid_operation $? "Error: could not update apt-get database list"

#
# Go to packages dir
#
cd packages

#
# Boost version 1.60.0
#
sudo dpkg -i terralib-boost_1.60.0_amd64.deb > /dev/null
boost_test=`dpkg -s terralib-boost | grep Status`

if [ "$boost_test" != "Status: install ok installed" ]; then
  sudo apt-get install -y -f
  sudo dpkg -i terralib-boost_1.60.0_amd64.deb
  valid_operation $? "Error: could not install boost! Please, install readline: sudo dpkg -i terralib-boost_1.60.0_amd64.deb" 
  echo "boost installed!"
else
  echo "boost installed!"
fi

#
# GDAL/OGR version 2.1.3
#
sudo dpkg -i terralib-gdal_2.1.3_amd64.deb > /dev/null
gdal_test=`dpkg -s terralib-gdal | grep Status`

if [ "$gdal_test" != "Status: install ok installed" ]; then
  sudo apt-get install -y -f
  sudo dpkg -i terralib-gdal_2.1.3_amd64.deb  
  valid_operation $? "Error: could not install gdal! Please, install readline: sudo dpkg -i terralib-gdal_2.1.3_amd64.deb" 
  echo "gdal installed!"
else
  echo "gdal installed!"
fi

#
# Qt Property Browser version 2.6.1
#
sudo dpkg -i terralib-qtpb_2.6.1_amd64.deb > /dev/null
qtpb_test=`dpkg -s terralib-qtpb | grep Status`

if [ "$qtpb_test" != "Status: install ok installed" ]; then
  sudo apt-get install -y -f
  sudo dpkg -i terralib-qtpb_2.6.1_amd64.deb
  valid_operation $? "Error: could not install qtpropertybrowser! Please, install readline: sudo dpkg -i terralib-qtpb_2.6.1_amd64.deb" 
  echo "qtpropertybrowser installed!"
else
  echo "qtpropertybrowser installed!"
fi

#
# Qwt version 6.1.2
#
sudo dpkg -i terralib-qwt_6.1.2_amd64.deb > /dev/null
qwt_test=`dpkg -s terralib-qwt| grep Status`

if [ "$qwt_test" != "Status: install ok installed" ]; then
  sudo apt-get install -y -f
  sudo dpkg -i terralib-qwt_6.1.2_amd64.deb
  valid_operation $? "Error: could not install qwt! Please, install readline: sudo dpkg -i terralib-qwt_6.1.2_amd64.deb" 
  echo "qwt installed!"
else
  echo "qwt installed!"
fi

#
# Wtss Cxx version 0.4.0
# 
sudo dpkg -i terralib-wtss-cxx_0.4.0_amd64.deb > /dev/null
wtss_test=`dpkg -s terralib-wtss-cxx| grep Status`

if [ "$wtss_test" != "Status: install ok installed" ]; then
  sudo apt-get install -y -f
  sudo dpkg -i terralib-wtss-cxx_0.4.0_amd64.deb
  valid_operation $? "Error: could not install wtss-cxx! Please, install readline: sudo dpkg -i terralib-wtss-cxx_0.4.0_amd64.deb" 
  echo "wtss-cxx installed!"
else
  echo "wtss-cxx installed!"
fi

#
# TerraLib version 5.2.2
#
sudo dpkg -i terralib-5.2.2.deb > /dev/null
terralib_test=`dpkg -s terralib-5.2.2 | grep Status`

if [ "$terralib_test" != "Status: install ok installed" ]; then
  sudo apt-get install -y -f
  sudo dpkg -i terralib-5.2.2.deb
  valid_operation $? "Error: could not install terralib! Please, install readline: sudo dpkg -i terralib-5.2.2.deb" 
  echo "terralib installed!"
else
  echo "terralib installed!"
fi

#
# TerraLib Layout version 1.2.0
#

if [ -f "terralib-layout_1.2.0_amd64.deb" ]; then
  sudo dpkg -i terralib-layout_1.2.0_amd64.deb > /dev/null
  terralib_layout_test=`dpkg -s terralib-layout | grep Status`

  if [ "$terralib_layout_test" != "Status: install ok installed" ]; then
    sudo apt-get install -y -f
    sudo dpkg -i terralib-layout_1.2.0_amd64.deb
    valid_operation $? "Error: could not install terralib layout! Please, install readline: sudo dpkg -i terralib-layout_1.2.0_amd64.deb" 
    echo "terralib layout installed!"
  else
    echo "terralib layout installed!"
  fi
fi

echo ""
echo "**************************"
echo "* Finished Successfully! *"
echo "**************************"
echo ""
