/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file terralib/layout/qt/outside/ImageGalleryDialogOutside.h

  \brief
*/

#ifndef __TERRALIB_LAYOUT_INTERNAL_IMAGE_GALLERY_OUTSIDE_H
#define __TERRALIB_LAYOUT_INTERNAL_IMAGE_GALLERY_OUTSIDE_H

// TerraLib
#include "terralib/qt/widgets/utils/DoubleListWidget.h"
#include "../../core/Config.h"
#ifndef Q_MOC_RUN
#include "../../core/pattern/mvc/AbstractOutsideView.h"
#endif

// STL
#include <memory>
#include <string>
#include <vector>
#include <list>

// Qt
#include <QDialog>
#include <QList>
#include <QSize>

class QListWidgetItem;
class QTreeWidgetItem;
class QString;
class QStringList;
class QListWidgetItem;
class QKeyEvent;

namespace Ui { class ImageGallery; }

namespace te
{
  namespace layout
  {
    class AbstractOutsideController;

    class TELAYOUTEXPORT ImageGalleryDialogOutside : public QDialog, public AbstractOutsideView
    {
      Q_OBJECT

      public:

        ImageGalleryDialogOutside(AbstractOutsideController* controller, QWidget* parent);

        ~ImageGalleryDialogOutside();

        /*!
          \brief Load layers in double widget.
        */
        virtual void init();
        
        virtual void setPosition( const double& x, const double& y );

        virtual te::gm::Coord2D getPosition();

        virtual void setPathsProperty( Property prop );

      signals:

        void updateProperty(Property prop);

        void updateProperties(std::vector<Property> props);
        
      protected slots:

        virtual void on_m_pbtnApply_clicked();

        virtual void on_m_pbtnOK_clicked();

        virtual void on_m_pbtnClose_clicked();

        virtual void on_m_pbtnAdd_clicked();

        virtual void on_m_pbtnRemove_clicked();
        
        virtual void on_m_treeGroups_itemClicked(QTreeWidgetItem* item, int column);
        
        virtual void on_m_listImages_currentItemChanged(QListWidgetItem * current, QListWidgetItem * previous);

        virtual void on_m_cmbIconSizes_currentIndexChanged(int index);

        virtual void on_m_lneFilter_textChanged(const QString & text);

      protected:

        virtual void keyPressEvent(QKeyEvent* e);

        virtual void loadTree();

        virtual void loadSettings();

        virtual void loadTable(QListWidgetItem* item);

        virtual void loadImages(const QList<QString>& listDir);

        virtual void loadComboIconSizes();

        virtual void loadCurrentPath();

        virtual void loadPrefixList();
        
        virtual QList<QString> getAllSubDirectories(const QString& topDir);

        virtual void addSvgToList(int index, const QString& file, const QString& fileName);

        virtual void addImageToList(int index, const QString& file, const QString& fileName);

        virtual QStringList getSupportedFormats();

        virtual bool add();

        virtual bool remove();

        virtual void addSubDirsToTree(QTreeWidgetItem* root, const QString& dir);

        virtual QTreeWidgetItem* createTreeItem(QTreeWidgetItem* parent, const QString& label, const QString& path, bool hasToolTip = false);

        QListWidgetItem* createListItem(int index, const QIcon& ico, const QString& fileName, const QString& completePath);

        virtual QList<QString> getAllPathsFromTree(QTreeWidgetItem* root);

        virtual void refreshCurrentTreeItem();

        virtual bool isBasicLibrary(QTreeWidgetItem* item);

        virtual bool isBasicLibrary(const QString& path);

        virtual void itemChanged(QTreeWidgetItem* item);

        virtual bool updateCurrentItemProperty();

        QString getSeparator(const QString& path);

        virtual void createBasicTreeItems();
        
      private:

        std::auto_ptr<Ui::ImageGallery>                   m_ui;
        Property                                          m_property;
        QString                                           m_currentFile;
        QSize                                             m_currentIconSize;
        QTreeWidgetItem*                                  m_library;
        QTreeWidgetItem*                                  m_folder;
    };
  }    
}     

#endif

