/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

This file is part of the TerraLib - a Framework for building GIS enabled applications.

TerraLib is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

TerraLib is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with TerraLib. See COPYING. If not, write to
TerraLib Team at <terralib-team@terralib.org>.
*/

/*!
\file terralib/vp/qt/CheckGeomValidityDialog.h

\brief A dialog used to check geometries validity.
*/

#ifndef __TERRALIB_VP_INTERNAL_CHECKGEOMVALIDITYDIALOG_H
#define __TERRALIB_VP_INTERNAL_CHECKGEOMVALIDITYDIALOG_H

// TerraLib
#ifndef Q_MOC_RUN
#include "../../dataaccess/dataset/ObjectIdSet.h"
#include "../../maptools/AbstractLayer.h"
#endif

#include "../Config.h"
#include "../../qt/widgets/canvas/MapDisplay.h"

// Qt
#include <QDialog>
#include <QTableWidgetItem>

namespace Ui { class CheckGeomValidityDialogForm; }

namespace te
{
  namespace gm
  {
    struct Coord2D;
  }

  namespace vp
  {
    /*!
    \class CheckGeomValidityDialog

    \brief A dialog used to check geometries validity.
    */
    class TEVPEXPORT CheckGeomValidityDialog : public QDialog
    {
      Q_OBJECT

      public:

        CheckGeomValidityDialog(QWidget* parent = 0, Qt::WindowFlags f = 0);

        /*! \brief Destructor. */
        ~CheckGeomValidityDialog();

        void setLayers(std::list<te::map::AbstractLayerPtr> layers, te::map::AbstractLayerPtr selectedLayer = 0);

        void setMapDisplay(te::qt::widgets::MapDisplay* md);

      private:

        void drawMark();

      protected slots:

        void onVerifyPushButtonClicked();

        void onFixPushButtonClicked();

        void onTableWidgetItemDoubleClicked(QTableWidgetItem* item);

        void onExtentChanged();

        void onDisplayPaintEvent(QPainter* painter);

      private:

        std::auto_ptr<Ui::CheckGeomValidityDialogForm> m_ui;

        te::qt::widgets::MapDisplay* m_mapDisplay;

        te::map::AbstractLayerPtr m_currentLayer;

        std::unique_ptr<te::gm::Point> m_currentCoord;

        std::unique_ptr<te::da::ObjectIdSet> m_oidSet;

        std::unique_ptr<QPixmap> m_markPixmap;

        bool m_drawMark;

    };
  }   // end namespace vp
}     // end namespace te

#endif  // __TERRALIB_VP_INTERNAL_CHECKGEOMVALIDITYDIALOG_H
