/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file terralib/vp/qt/GeometricOpDialog.h

  \brief A Qt dialog that allows users to run the basic geometric operations
  defined by VP module.
*/

#ifndef __TERRALIB_VP_INTERNAL_GEOMETRICOPDIALOG_H
#define __TERRALIB_VP_INTERNAL_GEOMETRICOPDIALOG_H

// TerraLib
#ifndef Q_MOC_RUN
#include "../../dataaccess/datasource/DataSourceInfo.h"
#include "../../maptools/AbstractLayer.h"
#endif
#include "../Config.h"
#include "../Enums.h"

// STL
#include <list>
#include <memory>

// Qt
#include <QDialog>

namespace Ui { class GeometricOpDialogForm; }

namespace te
{
  namespace vp
  {
    /*!
      \class GeometricOpDialog

      \brief This class is GUI used to define the wizard for the VP geometric
      operation.
    */
    class TEVPEXPORT GeometricOpDialog : public QDialog
    {
      Q_OBJECT

      public:

        GeometricOpDialog(QWidget* parent = 0, Qt::WindowFlags f = 0);

        ~GeometricOpDialog();

        void setLayers(std::list<te::map::AbstractLayerPtr> layers);

        te::map::AbstractLayerPtr getInLayer();

        std::vector<te::map::AbstractLayerPtr> getOutLayer();

        bool hasConvexHull();

        bool hasCentroid();

        bool hasMBR();

        bool hasArea();

        bool hasLine();

        bool hasPerimeter();

        void enableOperations(te::gm::GeomType type);

        bool isProjectionLatLong(const int& srid);

        te::vp::GeometricOpObjStrategy getObjectStrategy();

      protected slots:

        void onLayerComboBoxChanged(int index);

        void onAttributeComboBoxChanged(int index);

        void onAllObjectsToggled();

        void onAllLayerOperationToggled();

        void onAttributeOperationToggled();

        void onTargetDatasourceToolButtonPressed();

        void onTargetFileToolButtonPressed();

        void onOkPushButtonClicked();

        void onCancelPushButtonClicked();

        void onSrsToolButtonClicked();

      private:

        std::auto_ptr<Ui::GeometricOpDialogForm> m_ui;        //!< Qt Dialog Form

        std::list<te::map::AbstractLayerPtr> m_layers;        //!< List of layers.
        te::map::AbstractLayerPtr m_selectedLayer;            //!< Selected layer to operation
        te::da::DataSourceInfoPtr m_outputDatasource;         //!< DataSource information.
        std::vector<te::map::AbstractLayerPtr> m_outputLayer; //!< Generated Layer.
        std::vector<te::vp::GeometricOperation> m_ops;        //!< Operations selected to be executed.
        std::string m_attribute;                              //!< Properties related to the selected Layer to do the dissolve before operation.
        bool m_toFile;                                        //!< Flag to indicate if the output will be stored in a file.
        int m_newSRID;                                        //!< newSRID to compure tabular operations (Area, Perimeter, Line).
    };
  }     // end namespace vp
}       // end namespace te

#endif  // __TERRALIB_VP_INTERNAL_GEOMETRICOPDIALOG_H
